==> libopenmpt-0.4.53-pre.0+r24695.doc.tar.gz: libopenmpt-0.4.53-pre.0+r24695.doc/docs/libopenmpt_8hpp.js <==
var libopenmpt_8hpp =
[
    [ "probe_file_header_result", "libopenmpt_8hpp.html#ga2bfab5a4d171e48c0de55806174552b1", [
      [ "probe_file_header_result_success", "libopenmpt_8hpp.html#gga2bfab5a4d171e48c0de55806174552b1a30801347bba0cd61e700605a10d108b7", null ],
      [ "probe_file_header_result_failure", "libopenmpt_8hpp.html#gga2bfab5a4d171e48c0de55806174552b1a31d073e7dc36b213618f635ec90f5d2b", null ],
      [ "probe_file_header_result_wantmoredata", "libopenmpt_8hpp.html#gga2bfab5a4d171e48c0de55806174552b1acf3e6c33d72266e9c0d34da84fb7ec1f", null ]
    ] ],
    [ "could_open_probability", "libopenmpt_8hpp.html#ga95fd9b6781cd291b48a1c3e12a3c85e1", null ],
    [ "could_open_propability", "libopenmpt_8hpp.html#gaad5e4ff0e24869d7a9808ac4262283f2", null ],
    [ "get", "libopenmpt_8hpp.html#a5c14a09cfc6d93e26bd717c4b2cfd716", null ],
    [ "get_core_version", "libopenmpt_8hpp.html#gac37146367d4849a17a297d388cfb4811", null ],
    [ "get_library_version", "libopenmpt_8hpp.html#gaeece2f6ce1045a5f519c93ce19e6eef3", null ],
    [ "get_supported_extensions", "libopenmpt_8hpp.html#gaaa2081245974442462d76e8b9bc9380a", null ],
    [ "is_extension_supported", "libopenmpt_8hpp.html#gaafc5dab5b9c0b8324bbedcc01b59a3c0", null ],
    [ "probe_file_header", "libopenmpt_8hpp.html#gad77e7cf2361d664fda8ae8461c1dc7a0", null ],
    [ "probe_file_header", "libopenmpt_8hpp.html#ga77facf516dd9b626847f91ac26047336", null ],
    [ "probe_file_header", "libopenmpt_8hpp.html#ga6412e44030e40ca67aaa187691ad8e9c", null ],
    [ "probe_file_header_get_recommended_size", "libopenmpt_8hpp.html#gaf70a8d33fdceca5a821755106e840dcb", null ],
    [ "LIBOPENMPT_ATTR_DEPRECATED", "libopenmpt_8hpp.html#ab357d2a4b0fcc92eb1a45bb34ee214f5", null ],
    [ "probe_file_header_flags_containers", "libopenmpt_8hpp.html#gad8b455af763397bc1b331ab5a0e47526", null ],
    [ "probe_file_header_flags_default", "libopenmpt_8hpp.html#gae58576f977f7d74f12f37344223a0e78", null ],
    [ "probe_file_header_flags_modules", "libopenmpt_8hpp.html#ga92c11980bfec1deb5f5d4f8fa6e4e998", null ],
    [ "probe_file_header_flags_none", "libopenmpt_8hpp.html#ga631d4fb8e89a9f5f995827b07812c736", null ]
];

==> libopenmpt-0.5.41-pre.0+r24688.doc.tar.gz: libopenmpt-0.5.41-pre.0+r24688.doc/docs/libopenmpt_8hpp.js <==
var libopenmpt_8hpp =
[
    [ "probe_file_header_result", "libopenmpt_8hpp.html#ga2bfab5a4d171e48c0de55806174552b1", [
      [ "probe_file_header_result_success", "libopenmpt_8hpp.html#gga2bfab5a4d171e48c0de55806174552b1a30801347bba0cd61e700605a10d108b7", null ],
      [ "probe_file_header_result_failure", "libopenmpt_8hpp.html#gga2bfab5a4d171e48c0de55806174552b1a31d073e7dc36b213618f635ec90f5d2b", null ],
      [ "probe_file_header_result_wantmoredata", "libopenmpt_8hpp.html#gga2bfab5a4d171e48c0de55806174552b1acf3e6c33d72266e9c0d34da84fb7ec1f", null ]
    ] ],
    [ "could_open_probability", "libopenmpt_8hpp.html#ga95fd9b6781cd291b48a1c3e12a3c85e1", null ],
    [ "could_open_propability", "libopenmpt_8hpp.html#gaad5e4ff0e24869d7a9808ac4262283f2", null ],
    [ "get", "libopenmpt_8hpp.html#a5c14a09cfc6d93e26bd717c4b2cfd716", null ],
    [ "get_core_version", "libopenmpt_8hpp.html#gac37146367d4849a17a297d388cfb4811", null ],
    [ "get_library_version", "libopenmpt_8hpp.html#gaeece2f6ce1045a5f519c93ce19e6eef3", null ],
    [ "get_supported_extensions", "libopenmpt_8hpp.html#gaaa2081245974442462d76e8b9bc9380a", null ],
    [ "is_extension_supported", "libopenmpt_8hpp.html#ga499346669636c80f8df0d65145d3fed0", null ],
    [ "is_extension_supported2", "libopenmpt_8hpp.html#ga2377657c477285d9e47462247a755bc7", null ],
    [ "probe_file_header", "libopenmpt_8hpp.html#gaeb1b17a8535ac1407999a849340d7ef6", null ],
    [ "probe_file_header", "libopenmpt_8hpp.html#gad77e7cf2361d664fda8ae8461c1dc7a0", null ],
    [ "probe_file_header", "libopenmpt_8hpp.html#gaa3b9b7a7d0d3d791c8154bf330d96b01", null ],
    [ "probe_file_header", "libopenmpt_8hpp.html#ga77facf516dd9b626847f91ac26047336", null ],
    [ "probe_file_header", "libopenmpt_8hpp.html#ga6412e44030e40ca67aaa187691ad8e9c", null ],
    [ "probe_file_header_get_recommended_size", "libopenmpt_8hpp.html#gaf70a8d33fdceca5a821755106e840dcb", null ],
    [ "LIBOPENMPT_ATTR_DEPRECATED", "libopenmpt_8hpp.html#ab357d2a4b0fcc92eb1a45bb34ee214f5", null ],
    [ "probe_file_header_flags_containers", "libopenmpt_8hpp.html#gad8b455af763397bc1b331ab5a0e47526", null ],
    [ "probe_file_header_flags_default", "libopenmpt_8hpp.html#gae58576f977f7d74f12f37344223a0e78", null ],
    [ "probe_file_header_flags_modules", "libopenmpt_8hpp.html#ga92c11980bfec1deb5f5d4f8fa6e4e998", null ],
    [ "probe_file_header_flags_none", "libopenmpt_8hpp.html#ga631d4fb8e89a9f5f995827b07812c736", null ]
];
